@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Device::Onkyo;
-BEGIN {
-  $Device::Onkyo::VERSION = '1.120811';
+{
+  $Device::Onkyo::VERSION = '1.130210';
 }
 
 use Carp qw/croak carp/;
@@ -13,9 +13,7 @@ use Socket;
 use Symbol qw(gensym);
 use Time::HiRes;
 
-use constant {
-  DEBUG => $ENV{DEVICE_ONKYO_DEBUG},
-};
+use constant DEBUG => $ENV{DEVICE_ONKYO_DEBUG};
 
 # ABSTRACT: Perl module to control Onkyo/Integra AV equipment
 
@@ -87,18 +85,20 @@ sub _open_tcp_port {
 sub _open_serial_port {
   my $self = shift;
   $self->{type} = 'ISCP';
+  my $dev = $self->{device};
+  print STDERR "Opening $dev as serial port\n" if DEBUG;
   my $fh = gensym();
-  my $s = tie (*$fh, 'Device::SerialPort', $self->{device}) ||
-    croak "Could not tie serial port to file handle: $!\n";
-  $s->baudrate($self->baud);
-  $s->databits(8);
-  $s->parity("none");
-  $s->stopbits(1);
-  $s->datatype("raw");
-  $s->write_settings();
+  my $sport = tie (*$fh, 'Device::SerialPort', $dev) or
+    croak "Could not tie serial port, $dev, to file handle: $!";
+  $sport->baudrate($self->baud);
+  $sport->databits(8);
+  $sport->parity("none");
+  $sport->stopbits(1);
+  $sport->datatype("raw");
+  $sport->write_settings();
 
-  sysopen($fh, $self->{device}, O_RDWR|O_NOCTTY|O_NDELAY) or
-    croak "open of '".$self->{device}."' failed: $!\n";
+  sysopen $fh, $dev, O_RDWR|O_NOCTTY|O_NDELAY or
+    croak "sysopen of '$dev' failed: $!";
   $fh->autoflush(1);
   return $self->{filehandle} = $fh;
 }
@@ -107,6 +107,7 @@ sub _open_serial_port {
 sub read {
   my ($self, $timeout) = @_;
   my $res = $self->read_one(\$self->{_buf});
+  $self->_write_now() if (defined $res);
   return $res if (defined $res);
   my $fh = $self->filehandle;
   my $sel = IO::Select->new($fh);
@@ -125,7 +126,7 @@ sub read {
 
 
 sub read_one {
-  my ($self, $rbuf, $no_write) = @_;
+  my ($self, $rbuf) = @_;
   return unless ($$rbuf);
 
   print STDERR "rbuf=", _hexdump($$rbuf), "\n" if DEBUG;
@@ -148,14 +149,12 @@ sub read_one {
     $body =~ s/[\032\r\n]+$//;
     carp "Unexpected start/destination: expected '!1', got '$sd'\n"
       unless ($sd eq '!1');
-    $self->_write_now unless ($no_write);
     return $body;
   } else {
     return unless ($$rbuf =~ s/^(..)(....*?)[\032\r\n]+//);
     my ($sd, $body) = ($1, $2);
     carp "Unexpected start/destination: expected '!1', got '$sd'\n"
       unless ($sd eq '!1');
-    $self->_write_now unless ($no_write);
     return $body;
   }
 }
@@ -188,8 +187,8 @@ sub discover {
   my ($port, $addr) = sockaddr_in($sender);
   my $ip = inet_ntoa($addr);
   my $b = $buf;
-  my $msg = $self->read_one(\$b, 1); # don't uncork writes
-  ($port) = ($msg =~ m!/(\d{5})/../[0-9a-f]{12}!i);
+  my $msg = $self->read_one(\$b); # don't uncork writes
+  ($port) = ($msg =~ m!/(\d+)/../[0-9a-f]{12}$!i);
   print STDERR "discovered: $ip:$port ($msg)\n" if DEBUG;
   return [[$ip, $port]];
 }
@@ -389,7 +388,7 @@ Device::Onkyo - Perl module to control Onkyo/Integra AV equipment
 
 =head1 VERSION
 
-version 1.120811
+version 1.130210
 
 =head1 SYNOPSIS
 
@@ -490,16 +489,13 @@ This method blocks until a new message has been received by the
 device.  When a message is received the message string is returned.
 An optional timeout (in seconds) may be provided.
 
-=head2 C<read_one(\$buffer, [$do_not_write])>
+=head2 C<read_one(\$buffer)>
 
 This method attempts to remove a single message from the buffer
 passed in via the scalar reference.  When a message is removed a data
 structure is returned that represents the data received.  If insufficient
 data is available then undef is returned.
 
-By default, a received message triggers sending of the next queued message
-if the C<$do_no_write> parameter is set then writes are not triggered.
-
 =head2 C<discover()>
 
 This method attempts to discover available equipment.  It returns
